## 0.4.0 - 2022-12-05

### Added

- [#582](https://github.com/edgarrmondragon/citric/issues/582) Stable support for Python 3.11
- [#586](https://github.com/edgarrmondragon/citric/issues/586) Experimental support for Python 3.12

### Changed

- [#607](https://github.com/edgarrmondragon/citric/issues/607) Use keyword-only arguments for `add_participants` and `list_participants`

### Refactor

- [#626](https://github.com/edgarrmondragon/citric/issues/626) Refactor returns of the type `if: ... else: return ...`
